test_name 'Windows ACL Module - Change Owner to Local Unicode Group'

skip_test("This test requires QENG-449 to be resolved")

confine(:to, :platform => 'windows')

#Globals
user_type = 'local_unicode_group'
file_content = 'I thought things on a Saturday night.'

parent_name = 'temp'
target_name = "owner_#{user_type}.txt"

target_parent = "c:/#{parent_name}"
target = "#{target_parent}/#{target_name}"
user_id = 'bob'
owner_id = '䎈含㴼罍率䎁叴秀㪲軞'

verify_content_command = "cat /cygdrive/c/#{parent_name}/#{target_name}"
file_content_regex = /\A#{file_content}\z/

dosify_target = "c:\\#{parent_name}\\#{target_name}"
verify_owner_command = "cmd /c \"dir /q #{dosify_target}\""
owner_regex = /.*\\䎈含㴼罍率䎁叴秀㪲軞/

#Manifests
acl_manifest = <<-MANIFEST
file { "#{target_parent}":
  ensure => directory
}

file { "#{target}":
  ensure  => file,
  content => '#{file_content}',
  require => File['#{target_parent}']
}

group { "#{owner_id}":
  ensure     => present
}

user { "#{user_id}":
  ensure     => present,
  groups     => 'Users',
  managehome => true,
  password   => "L0v3Pupp3t!"
}

acl { "#{target}":
  permissions  => [
    { identity => '#{user_id}',
      rights   => ['modify']
    },
  ],
  owner        => '#{owner_id}'
}
MANIFEST

#Tests
agents.each do |agent|
  step "Execute ACL Manifest"
  on(agent, puppet('apply', '--debug'), :stdin => acl_manifest) do |result|
    assert_no_match(/Error:/, result.stderr, 'Unexpected error was detected!')
  end

  step "Verify that ACL Rights are Correct"
  on(agent, verify_owner_command) do |result|
    assert_match(owner_regex, result.stdout, 'Expected ACL was not present!')
  end

  step "Verify File Data Integrity"
  on(agent, verify_content_command) do |result|
    assert_match(file_content_regex, result.stdout, 'File content is invalid!')
  end
end
